"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const child_process_1 = require("child_process");
const tests_json_1 = tslib_1.__importDefault(require("./test/tests.json"));
const spec_json_1 = tslib_1.__importDefault(require("./test/spec.json"));
const json_patch_1 = require("../json-patch");
const equal = require('fast-deep-equal');
const bin = String(process.argv[2]);
if (!bin) {
    console.error('First argument should be argument to json-patch binary.');
    process.exit(1);
}
const testSuites = [
    {
        name: 'tests.json',
        tests: tests_json_1.default,
    },
    {
        name: 'spec.json',
        tests: spec_json_1.default,
    },
];
console.log('');
console.log(`Running JSON Patch tests.`);
console.log('');
let cntCorrect = 0;
let cntFailed = 0;
testSuites.forEach((suite) => {
    suite.tests.forEach((test) => {
        if (test.disabled)
            return;
        const testName = test.comment || test.error || JSON.stringify(test.patch);
        if (test.expected) {
            test.patch.forEach(json_patch_1.validateOperation);
            let isCorrect = false;
            try {
                const { stdout } = child_process_1.spawnSync(bin, [JSON.stringify(test.patch)], { input: JSON.stringify(test.doc) });
                const result = JSON.parse(stdout.toString());
                isCorrect = equal(result, test.expected);
            }
            catch (_a) {
                isCorrect = false;
            }
            if (isCorrect) {
                cntCorrect++;
                console.log('✅ ' + testName);
            }
            else {
                cntFailed++;
                console.error('🛑 ' + testName);
            }
        }
        else if (test.error || test.patch[0].op === 'test') {
            const { status } = child_process_1.spawnSync(bin, [JSON.stringify(test.doc), JSON.stringify(test.patch)]);
            if (status === 0) {
                cntFailed++;
                console.error('🛑 should fail: ' + testName);
            }
            else {
                cntCorrect++;
                console.log('✅ should fail: ' + testName);
            }
        }
        else {
            throw new Error('invalid test case');
        }
    });
});
console.log('');
console.log(`Successful = ${cntCorrect}, Failed = ${cntFailed}, Total = ${cntCorrect + cntFailed}`);
console.log('');
if (cntFailed > 0)
    process.exit(1);
