"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var child_process_1 = require("child_process");
var tests_json_1 = tslib_1.__importDefault(require("./test/tests.json"));
var spec_json_1 = tslib_1.__importDefault(require("./test/spec.json"));
var json_patch_1 = require("../json-patch");
var equal = require('fast-deep-equal');
var bin = String(process.argv[2]);
if (!bin) {
    console.error('First argument should be argument to json-patch binary.');
    process.exit(1);
}
var testSuites = [
    {
        name: 'tests.json',
        tests: tests_json_1.default,
    },
    {
        name: 'spec.json',
        tests: spec_json_1.default,
    },
];
console.log('');
console.log("Running JSON Patch tests.");
console.log('');
var cntCorrect = 0;
var cntFailed = 0;
testSuites.forEach(function (suite) {
    suite.tests.forEach(function (test) {
        if (test.disabled)
            return;
        var testName = test.comment || test.error || JSON.stringify(test.patch);
        if (test.expected) {
            test.patch.forEach(json_patch_1.validateOperation);
            var isCorrect = false;
            try {
                var stdout = child_process_1.spawnSync(bin, [JSON.stringify(test.patch)], { input: JSON.stringify(test.doc) }).stdout;
                var result = JSON.parse(stdout.toString());
                isCorrect = equal(result, test.expected);
            }
            catch (_a) {
                isCorrect = false;
            }
            if (isCorrect) {
                cntCorrect++;
                console.log('✅ ' + testName);
            }
            else {
                cntFailed++;
                console.error('🛑 ' + testName);
            }
        }
        else if (test.error || test.patch[0].op === 'test') {
            var status_1 = child_process_1.spawnSync(bin, [JSON.stringify(test.doc), JSON.stringify(test.patch)]).status;
            if (status_1 === 0) {
                cntFailed++;
                console.error('🛑 should fail: ' + testName);
            }
            else {
                cntCorrect++;
                console.log('✅ should fail: ' + testName);
            }
        }
        else {
            throw new Error('invalid test case');
        }
    });
});
console.log('');
console.log("Successful = " + cntCorrect + ", Failed = " + cntFailed + ", Total = " + (cntCorrect + cntFailed));
console.log('');
if (cntFailed > 0)
    process.exit(1);
